Module error_classification

Module error_classification 

Enums

RecoverableError
A transient fault for which retrying the same operation after a delay can succeed on its own, with no state change or user intervention.